# Generated by roxygen2: do not edit by hand

S3method(print,results.bayesian.erpm)
S3method(print,results.list.erpm)
S3method(print,results.p3.erpm)
export(Bell_constraints)
export(CUP)
export(Stirling2_constraints)
export(calculate_denominator_Dirichlet_restricted)
export(calculate_proba_Dirichlet_restricted)
export(check_sizes)
export(computeStatistics)
export(computeStatistics_multiple)
export(compute_averagesize)
export(compute_numgroups_denominator)
export(correlation_between)
export(correlation_with_size)
export(correlation_within)
export(count_classes)
export(draw_Metropolis_multiple)
export(draw_Metropolis_single)
export(estimate_ERPM)
export(estimate_logL)
export(estimate_multipleERPM)
export(exactestimates_numgroups)
export(find_all_partitions)
export(gridsearch_burnin_single)
export(gridsearch_burninthining_multiple)
export(gridsearch_burninthining_single)
export(gridsearch_thining_single)
export(group_size)
export(icc)
export(number_categories)
export(number_ties)
export(order_groupids)
export(phase1)
export(plot_averagesizes)
export(plot_numgroups_likelihood)
export(plot_partition)
export(proportion_isolate)
export(range_attribute)
export(run_phase1_multiple)
export(run_phase1_single)
export(run_phase2_multiple)
export(run_phase2_single)
export(run_phase3_multiple)
export(run_phase3_single)
export(same_pairs)
export(similar_pairs)
export(simulate_burnin_single)
export(simulate_burninthining_multiple)
export(simulate_burninthining_single)
export(simulate_thining_single)
importFrom(RColorBrewer,brewer.pal)
importFrom(grDevices,rgb)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,layout.auto)
importFrom(igraph,make_clusters)
importFrom(numbers,bell)
importFrom(snowfall,sfExport)
importFrom(snowfall,sfLapply)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dist)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(utils,combn)
